import type { Pipe } from './lift';
/** A Set wrapper providing extra functionalities and more chaining opportunities */
export declare class SetWrapper<T, S extends ReadonlySet<T>> {
    private _value;
    constructor(_value: S);
    private _isLiftWrapper;
    value(): S;
    clone(): SetWrapper<T, S>;
    private _clone;
    add(item: T): this;
    addAll(items: Iterable<T>): this;
    delete(item: T): this;
    clear(): this;
    collect<B>(iterator: (item: T) => B | void | undefined): SetWrapper<B, SetOf<S, B>>;
    /**
     * Filters this Set's items by aplying a predicate to all values and refine its type.
     */
    filter<B extends T>(predicate: (item: T) => item is B): SetWrapper<B, SetOf<S, B>>;
    /**
     * Filters this Set's items.
     */
    filter(predicate: (item: T) => boolean): SetWrapper<T, S>;
    /**
     * Returns the Set of all items of this Set that are also found in the passed Set.
     */
    intersection(other: ReadonlySet<T>): SetWrapper<T, S>;
    /**
     * Returns the Set of all items of this Set but not found in the passed Set.
     */
    difference(other: ReadonlySet<T>): SetWrapper<T, S>;
    toArray(): import("./array").ArrayWrapper<T[]>;
    pipe: typeof import("./lift").pipe;
}
export declare function setSetPipe(_pipe: Pipe): void;
declare type SetOf<T extends ReadonlySet<unknown>, ITEM> = T extends Set<any> ? Set<ITEM> : ReadonlySet<ITEM>;
export {};
